@@ -1,3 +1,7 @@
+// TODO: Allow user to input RPC endpoints instead of pigeon-holing them to one
+// Finish writing tests for currently supported chains
+// Add many more chains...
+
 use std::env;
 
 mod registry;
@@ -9,8 +13,7 @@ fn main() {
     let args: Vec<String> = env::args().collect();
     
     if args.iter().len() > 2 {
-        let chain = parse_chain(args.clone());
-        let chain = chain.unwrap();
+        let chain = parse_chain(args.clone()).unwrap();
         let query = from_flag(parse_flags(args.clone()).unwrap()).unwrap();
 
         let rpc = ChainRPC::new_and_launch(chain, &query.as_str()).unwrap();
@@ -32,15 +35,27 @@ mod tests {
         println!("{}", akt.last_response.unwrap())
     }
 
+    #[test]
+    fn evmos() {
+        let evmos = ChainRPC::new_and_launch(Chain::Evmos, "abci_info?").unwrap();
+        println!("{}", evmos.last_response.unwrap())
+    }
+
+    #[test]
+    fn gaia() {
+        let gaia = ChainRPC::new_and_launch(Chain::Gaia, "unconfirmed_txs?limit=100").unwrap();
+        println!("{}", gaia.last_response.unwrap())
+    }
+
     #[test]
     fn juno() {
-        let juno = ChainRPC::new_and_launch(Chain::Juno, "block_results?height=1090").unwrap(); 
+        let juno = ChainRPC::new_and_launch(Chain::Juno, "block_results?height=2578099").unwrap(); 
         println!("{}", juno.last_response.unwrap())
     }
 
     #[test]
     fn regen() {
-        let regen = ChainRPC::new_and_launch(Chain::Regen, "block_results?height=1090").unwrap();
+        let regen = ChainRPC::new_and_launch(Chain::Regen, "status?").unwrap();
         println!("{}", regen.last_response.unwrap())
     }
-}
\ No newline at end of file
+}
